package com.yunzhi.liyuanhui.controller;

import cn.binarywang.wx.miniapp.bean.WxMaJscode2SessionResult;
import com.yunzhi.liyuanhui.common.*;
import com.yunzhi.liyuanhui.entity.SysUser;
import com.yunzhi.liyuanhui.entity.TaPerson;
import com.yunzhi.liyuanhui.service.ISysUserService;
import com.yunzhi.liyuanhui.service.ITaPersonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.Map;

@RestController
public class LoginController extends BaseController {

    @Autowired
    ISysUserService iSysUserService;

    @Autowired
    ITaPersonService iTaPersonService;
    
    @Autowired
    WxUtils wxUtils;

    @PostMapping("/login")
    public ResponseBean login(@RequestBody Map<String, String> loginParam, HttpServletResponse response) throws Exception {
        if (null == loginParam) {
            return ResponseBean.error("账户或密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String userName = loginParam.get("username");
        String password = loginParam.get("password");

        if (StringUtils.isEmpty(userName) || StringUtils.isEmpty(password)) {
            return ResponseBean.error("账户或密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        SysUser sysUser = iSysUserService.getLoginUser(userName);
        if (null == sysUser) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!checkPassword(password, sysUser.getPassword(), sysUser.getUserId().toString())) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!iSysUserService.checkStatus(sysUser)) {
            return ResponseBean.error("用户状态不正确, 请联系管理人员", ResponseBean.ERROR_UNAVAILABLE);
        }

        // 生成 token
        Map<String, Object> claims = new HashMap<String, Object>(){{
            put("id", sysUser.getUserId());
        }};
        String jws = JWTUtils.encode(claims);
        response.addHeader(JWTUtils.AUTH_HEADER, jws);

        sysUser.setPassword(null);
        return ResponseBean.success(sysUser);
    }

    private boolean checkPassword(String src, String targ, String salt) {
        return EncryptUtils.md5(src, salt).equals(targ);
    }

    @PostMapping("/logout")
    public ResponseBean logout() {
        return ResponseBean.success(null);
    }

    /**
     * 微信登录
     * @param code
     * @return
     * @throws Exception
     */
    @PostMapping("/wx/login")
    public ResponseBean wxLogin(@RequestParam(value = "code") String code, HttpServletResponse response) throws Exception{
        WxMaJscode2SessionResult sessionInfo = wxUtils.getService().getUserService().getSessionInfo(code);

        // 获取个人信息
        TaPerson taPerson = iTaPersonService.getOrSavePerson(sessionInfo.getOpenid());

        // 其余信息
        Map<String, Object> extraInfo = new HashMap<>();
        extraInfo.put("sessionKey", sessionInfo.getSessionKey());

        //
        Map<String, Object> result = new HashMap<>();
        result.put("person", taPerson);
        result.put("extraInfo", extraInfo);


        // 生成 token
        Map<String, Object> claims = new HashMap<String, Object>(){{
            put("id", taPerson.getPersonId());
        }};
        response.addHeader(JWTUtils.AUTH_HEADER, JWTUtils.encode(claims));

        return ResponseBean.success(result);
    }
}
