package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import com.yunzhi.liyuanhui.enums.StatusEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ISysModuleService;
import com.yunzhi.liyuanhui.entity.SysModule;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 模块 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class SysModuleController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysModuleController.class);

    @Autowired
    public ISysModuleService iSysModuleService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/sysModule",method= RequestMethod.GET)
    public ResponseBean sysModuleList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                      @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<SysModule> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<SysModule> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("status", StatusEnum.NORMAL.getCode());

        IPage<SysModule> result = iSysModuleService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param sysModule 实体对象
     * @return
     */
    @RequestMapping(value="/sysModule",method= RequestMethod.POST)
    public ResponseBean sysModuleAdd(@RequestBody SysModule sysModule) throws Exception{
        if (iSysModuleService.save(sysModule)){
            return ResponseBean.success(sysModule);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/sysModule/{id}", method= RequestMethod.DELETE)
    public ResponseBean sysModuleDelete(@PathVariable Integer id) throws Exception{

        if(iSysModuleService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param sysModule 实体对象
     * @return
     */
    @RequestMapping(value="/sysModule/{id}",method= RequestMethod.PUT)
    public ResponseBean sysModuleUpdate(@PathVariable Integer id,
                                        @RequestBody SysModule sysModule) throws Exception{

        if (iSysModuleService.updateById(sysModule)){
            return ResponseBean.success(sysModule);
        }else {
            return ResponseBean.error("更新失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/sysModule/{id}",method= RequestMethod.GET)
    public ResponseBean sysModuleGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iSysModuleService.getById(id));
    }
}
