package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import com.yunzhi.liyuanhui.entity.TaPerson;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITaActivityEnrollService;
import com.yunzhi.liyuanhui.entity.TaActivityEnroll;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 活动报名 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class TaActivityEnrollController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaActivityEnrollController.class);

    @Autowired
    public ITaActivityEnrollService iTaActivityEnrollService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/activityEnroll",method= RequestMethod.GET)
    public ResponseBean taActivityEnrollList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                             @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                             @RequestParam(value ="activityId") Integer activityId) throws Exception{

        IPage<TaActivityEnroll> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaActivityEnroll> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("activity_id", activityId);
        queryWrapper.orderByDesc("create_date");

        IPage<TaActivityEnroll> result = iTaActivityEnrollService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taActivityEnroll 实体对象
     * @return
     */
    @RequestMapping(value="/wx/activity/{activityId}/enroll",method= RequestMethod.POST)
    public ResponseBean taActivityEnrollAdd(@PathVariable Integer activityId,
                                            @RequestBody TaActivityEnroll taActivityEnroll,
                                            HttpServletRequest request) throws Exception{
        if (null == taActivityEnroll) {
            return ResponseBean.error("请填写报名信息", ResponseBean.ERROR_MISSING_PARAMS);
        } else {
            taActivityEnroll.setActivityId(activityId);
        }

        TaPerson taPerson = getPerson(request);
        if (iTaActivityEnrollService.enroll(taActivityEnroll, taPerson)){
            return ResponseBean.success(taActivityEnroll);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taActivityEnroll/{id}", method= RequestMethod.DELETE)
    public ResponseBean taActivityEnrollDelete(@PathVariable Integer id) throws Exception{

        if(iTaActivityEnrollService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taActivityEnroll 实体对象
     * @return
     */
    @RequestMapping(value="/taActivityEnroll/{id}",method= RequestMethod.PUT)
    public ResponseBean taActivityEnrollUpdate(@PathVariable Integer id,
                                        @RequestBody TaActivityEnroll taActivityEnroll) throws Exception{

        if (iTaActivityEnrollService.updateById(taActivityEnroll)){
            return ResponseBean.success(taActivityEnroll);
        }else {
            return ResponseBean.error("更新失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taActivityEnroll/{id}",method= RequestMethod.GET)
    public ResponseBean taActivityEnrollGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaActivityEnrollService.getById(id));
    }
}
