package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import com.yunzhi.liyuanhui.entity.TaActivity;
import com.yunzhi.liyuanhui.entity.TaActivityVoteItem;
import com.yunzhi.liyuanhui.entity.TaPerson;
import com.yunzhi.liyuanhui.enums.StatusEnum;
import com.yunzhi.liyuanhui.service.ITaActivityService;
import com.yunzhi.liyuanhui.service.ITaActivityVoteItemService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITaActivityVoteService;
import com.yunzhi.liyuanhui.entity.TaActivityVote;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/**
 * <p>
    * 活动投票 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class TaActivityVoteController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaActivityVoteController.class);

    @Autowired
    public ITaActivityVoteService iTaActivityVoteService;

    @Autowired
    private ITaActivityService iTaActivityService;

    @Autowired
    private ITaActivityVoteItemService iTaActivityVoteItemService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/activity/{activityId}/vote",method= RequestMethod.GET)
    public ResponseBean taActivityVoteList(@PathVariable Integer activityId,
                                           @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TaActivityVote> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaActivityVote> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("activity_id", activityId);
        queryWrapper.orderByDesc("create_date");

        IPage<TaActivityVote> result = iTaActivityVoteService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 活动投票
     * @param activityId
     * @param params
     * @param request
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/wx/activity/{activityId}/vote",method= RequestMethod.POST)
    public ResponseBean taActivityVoteAdd(@PathVariable Integer activityId,
                                          @RequestBody Map<String, Object> params,
                                          HttpServletRequest request) throws Exception{
        if (null == params) {
            return ResponseBean.error("投票失败, 请设置投票内容", ResponseBean.ERROR_MISSING_PARAMS);
        }

        Object itemId = params.get("itemId");
        if (null == itemId) {
            return ResponseBean.error("投票失败, 请选择设置投票项目", ResponseBean.ERROR_MISSING_PARAMS);
        }

        TaActivity taActivity = iTaActivityService.getById(activityId);
        TaPerson taPerson = getPerson(request);
        TaActivityVoteItem taActivityVoteItem = iTaActivityVoteItemService.getById(Integer.valueOf(itemId.toString()));

        if (iTaActivityVoteService.vote(taActivity, taActivityVoteItem, taPerson)){
            return ResponseBean.success("投票成功");
        }else {
            return ResponseBean.error("投票失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taActivityVote/{id}", method= RequestMethod.DELETE)
    public ResponseBean taActivityVoteDelete(@PathVariable Integer id) throws Exception{

        if(iTaActivityVoteService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taActivityVote 实体对象
     * @return
     */
    @RequestMapping(value="/taActivityVote/{id}",method= RequestMethod.PUT)
    public ResponseBean taActivityVoteUpdate(@PathVariable Integer id,
                                        @RequestBody TaActivityVote taActivityVote) throws Exception{

        if (iTaActivityVoteService.updateById(taActivityVote)){
            return ResponseBean.success(taActivityVote);
        }else {
            return ResponseBean.error("更新失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taActivityVote/{id}",method= RequestMethod.GET)
    public ResponseBean taActivityVoteGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaActivityVoteService.getById(id));
    }
}
