package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITaActivityVoteItemService;
import com.yunzhi.liyuanhui.entity.TaActivityVoteItem;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * <p>
    * 投票项目  前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-11
 */
@RestController
@RequestMapping("/")
public class TaActivityVoteItemController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaActivityVoteItemController.class);

    @Autowired
    public ITaActivityVoteItemService iTaActivityVoteItemService;

    /**
     *
     * @param client
     * @param activityId
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/{client}/activity/{activityId}/voteitem",method= RequestMethod.GET)
    public ResponseBean taActivityVoteItemList(@PathVariable String client,
                                               @PathVariable Integer activityId) throws Exception{

        List<TaActivityVoteItem> result = iTaActivityVoteItemService.getAllAvailableItems(activityId);
        return ResponseBean.success(result);
    }

    /**
     *
     * @param activityId
     * @param voteItems
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/admin/activity/{activityId}/voteitem",method= RequestMethod.POST)
    public ResponseBean taActivityVoteItemAdd(@PathVariable Integer activityId,
                                              @RequestBody List<TaActivityVoteItem> voteItems) throws Exception{
        if (null == voteItems) {
            return ResponseBean.error("未发现需要保存内容", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        List<TaActivityVoteItem> result = iTaActivityVoteItemService.mergeBy(activityId, voteItems);
        return ResponseBean.success(result);
    }

    @RequestMapping(value="/{plat}/activity/{activityId}/voteitem/rank",method= RequestMethod.GET)
    public ResponseBean taActivityVoteItemAdd(@PathVariable Integer activityId) throws Exception{
        List<Map<String, Object>> result = iTaActivityVoteItemService.getVoteRank(activityId);
        return ResponseBean.success(result);
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/activityVoteItem/{id}", method= RequestMethod.DELETE)
    public ResponseBean taActivityVoteItemDelete(@PathVariable Integer id) throws Exception{
        if(iTaActivityVoteItemService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taActivityVoteItem 实体对象
     * @return
     */
    @RequestMapping(value="/taActivityVoteItem/{id}",method= RequestMethod.PUT)
    public ResponseBean taActivityVoteItemUpdate(@PathVariable Integer id,
                                        @RequestBody TaActivityVoteItem taActivityVoteItem) throws Exception{
        if (iTaActivityVoteItemService.updateById(taActivityVoteItem)){
            return ResponseBean.success(taActivityVoteItem);
        }else {
            return ResponseBean.error("修改失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taActivityVoteItem/{id}",method= RequestMethod.GET)
    public ResponseBean taActivityVoteItemGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaActivityVoteItemService.getById(id));
    }
}
