package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import com.yunzhi.liyuanhui.common.StringUtils;
import com.yunzhi.liyuanhui.enums.StatusEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITaAdvertService;
import com.yunzhi.liyuanhui.entity.TaAdvert;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 广告位  前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-13
 */
@RestController
@RequestMapping("/")
public class TaAdvertController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaAdvertController.class);

    @Autowired
    public ITaAdvertService iTaAdvertService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/advert",method= RequestMethod.GET)
    public ResponseBean taAdvertList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                     @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                     @RequestParam(value ="title", required = false) String title,
                                     @RequestParam(value ="position", required = false) String position,
                                     @RequestParam(value ="status", required = false) Integer status,
                                     @PathVariable String client) throws Exception{

        IPage<TaAdvert> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaAdvert> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(title), "title", title);
        queryWrapper.eq(!StringUtils.isEmpty(position), "position", position);
        queryWrapper.eq(status != null, "status", status);
        queryWrapper.orderByDesc("sort_no");
        queryWrapper.orderByDesc("create_date");

        IPage<TaAdvert> result = iTaAdvertService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taAdvert 实体对象
     * @return
     */
    @RequestMapping(value="/admin/advert",method= RequestMethod.POST)
    public ResponseBean taAdvertAdd(@RequestBody TaAdvert taAdvert) throws Exception{

        if (iTaAdvertService.save(taAdvert)){
            return ResponseBean.success(taAdvert);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taAdvert/{id}", method= RequestMethod.DELETE)
    public ResponseBean taAdvertDelete(@PathVariable Integer id) throws Exception{

        if(iTaAdvertService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taAdvert 实体对象
     * @return
     */
    @RequestMapping(value="/admin/advert/{id}",method= RequestMethod.PUT)
    public ResponseBean taAdvertUpdate(@PathVariable Integer id,
                                        @RequestBody TaAdvert taAdvert) throws Exception{

        if (iTaAdvertService.updateById(taAdvert)){
            return ResponseBean.success(taAdvert);
        }else {
            return ResponseBean.error("修改失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/advert/{id}",method= RequestMethod.GET)
    public ResponseBean taAdvertGet(@PathVariable Integer id) throws Exception{

        return ResponseBean.success(iTaAdvertService.getById(id));
    }
}
