package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import com.yunzhi.liyuanhui.common.StringUtils;
import com.yunzhi.liyuanhui.enums.StatusEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITaGalleryService;
import com.yunzhi.liyuanhui.entity.TaGallery;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 照片墙 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class TaGalleryController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaGalleryController.class);

    @Autowired
    public ITaGalleryService iTaGalleryService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/gallery",method= RequestMethod.GET)
    public ResponseBean taGalleryList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                      @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                      @RequestParam(value = "typeId", required = false) String typeId) throws Exception{

        IPage<TaGallery> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaGallery> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(!StringUtils.isEmpty(typeId), "type_id", typeId);
        queryWrapper.eq("status", StatusEnum.NORMAL.getCode());
        queryWrapper.orderByAsc("create_date");

        IPage<TaGallery> result = iTaGalleryService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taGallery 实体对象
     * @return
     */
    @RequestMapping(value="/admin/gallery",method= RequestMethod.POST)
    public ResponseBean taGalleryAdd(@RequestBody TaGallery taGallery) throws Exception{

        if (iTaGalleryService.save(taGallery)){
            return ResponseBean.success(taGallery);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taGallery/{id}", method= RequestMethod.DELETE)
    public ResponseBean taGalleryDelete(@PathVariable Integer id) throws Exception{

        if(iTaGalleryService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taGallery 实体对象
     * @return
     */
    @RequestMapping(value="/taGallery/{id}",method= RequestMethod.PUT)
    public ResponseBean taGalleryUpdate(@PathVariable Integer id,
                                        @RequestBody TaGallery taGallery) throws Exception{

        if (iTaGalleryService.updateById(taGallery)){
            return ResponseBean.success(taGallery);
        }else {
            return ResponseBean.error("更新失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taGallery/{id}",method= RequestMethod.GET)
    public ResponseBean taGalleryGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaGalleryService.getById(id));
    }
}
