package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import com.yunzhi.liyuanhui.common.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITaNewsService;
import com.yunzhi.liyuanhui.entity.TaNews;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 资讯 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class TaNewsController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaNewsController.class);

    @Autowired
    public ITaNewsService iTaNewsService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/news",method= RequestMethod.GET)
    public ResponseBean taNewsList(@PathVariable String client,
                                   @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                   @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                   @RequestParam(value = "typeId", required = false) Integer typeId,
                                   @RequestParam(value = "title", required = false) String title,
                                   @RequestParam(value = "status", required = false) Integer status) throws Exception{

        IPage<TaNews> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaNews> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(null != typeId, "type_id", typeId);
        queryWrapper.like(!StringUtils.isEmpty(title), "title", title);
        queryWrapper.eq(null != status, "status", status);
        queryWrapper.orderByDesc("create_date");

        IPage<TaNews> result = iTaNewsService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taNews 实体对象
     * @return
     */
    @RequestMapping(value="/admin/news",method= RequestMethod.POST)
    public ResponseBean taNewsAdd(@RequestBody TaNews taNews) throws Exception{

        if (iTaNewsService.save(taNews)){
            return ResponseBean.success(taNews);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taNews/{id}", method= RequestMethod.DELETE)
    public ResponseBean taNewsDelete(@PathVariable Integer id) throws Exception{

        if(iTaNewsService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taNews 实体对象
     * @return
     */
    @RequestMapping(value="/admin/news/{id}",method= RequestMethod.PUT)
    public ResponseBean taNewsUpdate(@PathVariable Integer id,
                                     @RequestBody TaNews taNews) throws Exception{

        if (iTaNewsService.updateById(taNews)){
            return ResponseBean.success(taNews);
        }else {
            return ResponseBean.error("更新失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/news/{id}",method= RequestMethod.GET)
    public ResponseBean taNewsGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaNewsService.getById(id));
    }
}
