package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITaRecommendSettingService;
import com.yunzhi.liyuanhui.entity.TaRecommendSetting;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 推荐设置 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class TaRecommendSettingController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaRecommendSettingController.class);

    @Autowired
    public ITaRecommendSettingService iTaRecommendSettingService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taRecommendSetting",method= RequestMethod.GET)
    public ResponseBean taRecommendSettingList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                               @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TaRecommendSetting> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaRecommendSetting> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("create_date");

        IPage<TaRecommendSetting> result = iTaRecommendSettingService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taRecommendSetting 实体对象
     * @return
     */
    @RequestMapping(value="/taRecommendSetting",method= RequestMethod.POST)
    public ResponseBean taRecommendSettingAdd(@RequestBody TaRecommendSetting taRecommendSetting) throws Exception{

        if (iTaRecommendSettingService.save(taRecommendSetting)){
            return ResponseBean.success(taRecommendSetting);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taRecommendSetting/{id}", method= RequestMethod.DELETE)
    public ResponseBean taRecommendSettingDelete(@PathVariable Integer id) throws Exception{

        if(iTaRecommendSettingService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taRecommendSetting 实体对象
     * @return
     */
    @RequestMapping(value="/taRecommendSetting/{id}",method= RequestMethod.PUT)
    public ResponseBean taRecommendSettingUpdate(@PathVariable Integer id,
                                        @RequestBody TaRecommendSetting taRecommendSetting) throws Exception{

        if (iTaRecommendSettingService.updateById(taRecommendSetting)){
            return ResponseBean.success(taRecommendSetting);
        }else {
            return ResponseBean.error("更新失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taRecommendSetting/{id}",method= RequestMethod.GET)
    public ResponseBean taRecommendSettingGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaRecommendSettingService.getById(id));
    }
}
