package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import com.yunzhi.liyuanhui.enums.StatusEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITdActivityTypeService;
import com.yunzhi.liyuanhui.entity.TdActivityType;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 活动类型 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class TdActivityTypeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdActivityTypeController.class);

    @Autowired
    public ITdActivityTypeService iTdActivityTypeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/activityType",method= RequestMethod.GET)
    public ResponseBean tdActivityTypeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @RequestParam(value ="pageSize",defaultValue = "100") Integer pageSize,
                                           @PathVariable String client) throws Exception{

        IPage<TdActivityType> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TdActivityType> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("status", StatusEnum.NORMAL.getCode());
        queryWrapper.orderByDesc("sort_no");

        IPage<TdActivityType> result = iTdActivityTypeService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param tdActivityType 实体对象
     * @return
     */
    @RequestMapping(value="/tdActivityType",method= RequestMethod.POST)
    public ResponseBean tdActivityTypeAdd(@RequestBody TdActivityType tdActivityType) throws Exception{

        if (iTdActivityTypeService.save(tdActivityType)){
            return ResponseBean.success(tdActivityType);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/tdActivityType/{id}", method= RequestMethod.DELETE)
    public ResponseBean tdActivityTypeDelete(@PathVariable Integer id) throws Exception{

        if(iTdActivityTypeService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tdActivityType 实体对象
     * @return
     */
    @RequestMapping(value="/tdActivityType/{id}",method= RequestMethod.PUT)
    public ResponseBean tdActivityTypeUpdate(@PathVariable Integer id,
                                        @RequestBody TdActivityType tdActivityType) throws Exception{

        if (iTdActivityTypeService.updateById(tdActivityType)){
            return ResponseBean.success(tdActivityType);
        }else {
            return ResponseBean.error("修改失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tdActivityType/{id}",method= RequestMethod.GET)
    public ResponseBean tdActivityTypeGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTdActivityTypeService.getById(id));
    }
}
