package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITdNewsTypeService;
import com.yunzhi.liyuanhui.entity.TdNewsType;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 资讯类型 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class TdNewsTypeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdNewsTypeController.class);

    @Autowired
    public ITdNewsTypeService iTdNewsTypeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/tdNewsType",method= RequestMethod.GET)
    public ResponseBean tdNewsTypeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TdNewsType> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TdNewsType> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("create_date");

        IPage<TdNewsType> result = iTdNewsTypeService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param tdNewsType 实体对象
     * @return
     */
    @RequestMapping(value="/tdNewsType",method= RequestMethod.POST)
    public ResponseBean tdNewsTypeAdd(@RequestBody TdNewsType tdNewsType) throws Exception{

        if (iTdNewsTypeService.save(tdNewsType)){
            return ResponseBean.success(tdNewsType);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/tdNewsType/{id}", method= RequestMethod.DELETE)
    public ResponseBean tdNewsTypeDelete(@PathVariable Integer id) throws Exception{

        if(iTdNewsTypeService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tdNewsType 实体对象
     * @return
     */
    @RequestMapping(value="/tdNewsType/{id}",method= RequestMethod.PUT)
    public ResponseBean tdNewsTypeUpdate(@PathVariable Integer id,
                                        @RequestBody TdNewsType tdNewsType) throws Exception{

        if (iTdNewsTypeService.updateById(tdNewsType)){
            return ResponseBean.success(tdNewsType);
        }else {
            return ResponseBean.error("更新失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tdNewsType/{id}",method= RequestMethod.GET)
    public ResponseBean tdNewsTypeGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTdNewsTypeService.getById(id));
    }
}
