package com.yunzhi.liyuanhui.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.yunzhi.liyuanhui.common.StringUtils;
import com.yunzhi.liyuanhui.entity.TaActivity;
import com.yunzhi.liyuanhui.entity.TaActivityEnroll;
import com.yunzhi.liyuanhui.entity.TaPerson;
import com.yunzhi.liyuanhui.enums.StatusEnum;
import com.yunzhi.liyuanhui.mapper.TaActivityEnrollMapper;
import com.yunzhi.liyuanhui.service.ITaActivityEnrollService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yunzhi.liyuanhui.service.ITaActivityService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * 活动报名 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@Service
public class TaActivityEnrollServiceImpl extends ServiceImpl<TaActivityEnrollMapper, TaActivityEnroll> implements ITaActivityEnrollService {

    @Autowired
    ITaActivityService iTaActivityService;

    @Transactional
    @Override
    public boolean enroll(TaActivityEnroll taActivityEnroll, TaPerson taPerson) throws Exception {
        TaActivity taActivity = iTaActivityService.getById(taActivityEnroll.getActivityId());

        if (null == taActivity || !StatusEnum.NORMAL.getCode().equals(taActivity.getStatus()) || !taActivity.getIsEnroll()) {
            throw new Exception("当前活动暂不支持报名");
        }

        if (StringUtils.isEmpty(taPerson.getPhone())) {
            throw new Exception("请先进行授权手机号操作");
        }

        if (StringUtils.isEmpty(taActivityEnroll.getEnrollName()) || StringUtils.isEmpty(taActivityEnroll.getEnrollPhone())) {
            throw new Exception("报名人或者手机号不能为空");
        }

        if (null == taActivityEnroll.getEnrollNum() || 0 >= taActivityEnroll.getEnrollNum()) {
            taActivityEnroll.setEnrollNum(1);
        }

        // 判断当前手机号是否已经报名
        QueryWrapper<TaActivityEnroll> queryWrapper = new QueryWrapper<>();
        queryWrapper.nested(q -> q.eq("person_phone", taPerson.getPhone())
                .or().eq("person_phone", taActivityEnroll.getEnrollPhone())
                .or().eq("enroll_phone", taPerson.getPhone())
                .or().eq("enroll_phone", taActivityEnroll.getEnrollPhone()));
        int count = this.count(queryWrapper);
        if (count > 0) {
            throw new Exception("当前人员或所填手机号已经报名");
        }

        taActivityEnroll.setActivityName(taActivity.getName());
        taActivityEnroll.setActivityThumb(taActivity.getThumb());
        taActivityEnroll.setActivityTypeId(taActivity.getTypeId());
        taActivityEnroll.setActivityTypeName(taActivity.getTypeName());
        taActivityEnroll.setPersonId(taPerson.getPersonId());
        taActivityEnroll.setPersonName(StringUtils.ifNull(taPerson.getName(), taPerson.getNickname()));
        taActivityEnroll.setPersonPhone(taPerson.getPhone());

        if(!save(taActivityEnroll)) {
            throw new RuntimeException("报名失败, 请重试");
        }

        // 更新投票人数
        UpdateWrapper<TaActivity> updateWrapper = new UpdateWrapper<>();
        updateWrapper.set("enroll_num", taActivity.getEnrollNum() + 1);
        updateWrapper.eq("activity_id", taActivity.getActivityId());
        updateWrapper.eq("enroll_num", taActivity.getEnrollNum());
        boolean update = iTaActivityService.update(updateWrapper);
        if (!update) {
            throw new RuntimeException("报名失败, 请重试");
        }

        return true;
    }
}
