package com.yunzhi.liyuanhui.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.yunzhi.liyuanhui.entity.TaActivityVoteItem;
import com.yunzhi.liyuanhui.enums.StatusEnum;
import com.yunzhi.liyuanhui.mapper.TaActivityVoteItemMapper;
import com.yunzhi.liyuanhui.service.ITaActivityVoteItemService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 投票项目  服务实现类
 * </p>
 *
 * @author yansen
 * @since 2020-08-11
 */
@Service
public class TaActivityVoteItemServiceImpl extends ServiceImpl<TaActivityVoteItemMapper, TaActivityVoteItem> implements ITaActivityVoteItemService {

    @Autowired
    TaActivityVoteItemMapper taActivityVoteItemMapper;

    @Override
    public List<TaActivityVoteItem> mergeBy(Integer activityId, List<TaActivityVoteItem> voteItems) throws Exception {
        // 如果是一个没有, 则认为是全部删除
        if (voteItems == null || voteItems.size() == 0) {
            UpdateWrapper<TaActivityVoteItem> updateWrapper = new UpdateWrapper<>();
            updateWrapper.set("status", StatusEnum.DELETED.getCode());
            updateWrapper.eq("activity_id", activityId);

            this.update(updateWrapper);
            return null;
        }

        // 如果数据库中没有已经存在的, 则全部保存
        List<Integer> existsIds = taActivityVoteItemMapper.selectIdsByActivity(activityId);
        if (null == existsIds || existsIds.size() == 0) {
            for(TaActivityVoteItem item : voteItems) {
                item.setActivityId(activityId);
                this.save(item);
            }
        } else {

            // 否则遍历去 merge
            for(TaActivityVoteItem item : voteItems) {
                if (null == item.getItemId() || item.getItemId() < 1) {
                    item.setActivityId(activityId);
                    this.save(item);
                } else {
                    this.updateById(item);

                    // 数据中心已经存在的 减去 正常更新的 , 剩余就是被删除的
                    existsIds.remove(item.getActivityId());
                }
            }

            if (existsIds.size() > 0) {
                UpdateWrapper<TaActivityVoteItem> updateWrapper1 = new UpdateWrapper<>();
                updateWrapper1.set("status", StatusEnum.DELETED.getCode());
                updateWrapper1.in("item_id", existsIds);
                update(updateWrapper1);
            }
        }

        return getAllAvailableItems(activityId);
    }

    @Override
    public List<TaActivityVoteItem> getAllAvailableItems(Integer activityId) {

        QueryWrapper<TaActivityVoteItem> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("activity_id", activityId);
        queryWrapper.eq("status", StatusEnum.NORMAL.getCode());
        queryWrapper.orderByAsc("sort_no");
        queryWrapper.orderByDesc("create_date");

        return list(queryWrapper);
    }

    @Override
    public List<Map<String, Object>> getVoteRank(Integer activityId) throws Exception {
        return taActivityVoteItemMapper.getVoteRank(activityId);
    }
}
